@@ -4,7 +4,7 @@
 #	Class 'ppm' representing fitted point process models.
 #
 #
-#	$Revision: 2.123 $	$Date: 2015/08/27 08:10:31 $
+#	$Revision: 2.127 $	$Date: 2015/10/16 07:47:19 $
 #
 #       An object of class 'ppm' contains the following:
 #
@@ -561,7 +561,22 @@ emend.ppm <- project.ppm <- local({
 
 # more methods
 
-logLik.ppm <- function(object, ..., new.coef=NULL, warn=TRUE) {
+deviance.ppm <- function(object, ...) {
+  satlogpl <- object$satlogpl
+  if(is.null(satlogpl)) {
+    object <- update(object, forcefit=TRUE)
+    satlogpl <- object$satlogpl
+  }
+  if(is.null(satlogpl) || !is.finite(satlogpl))
+    return(NA)
+  ll <- do.call(logLik,
+                resolve.defaults(list(object=object, absolute=FALSE),
+                                 list(...)))
+  ll <- as.numeric(ll)
+  2 * (satlogpl - ll)
+}
+
+logLik.ppm <- function(object, ..., new.coef=NULL, warn=TRUE, absolute=FALSE) {
   if(!is.poisson.ppm(object) && warn) 
     warning(paste("log likelihood is not available for non-Poisson model;",
                   "log-pseudolikelihood returned"))
@@ -569,10 +584,19 @@ logLik.ppm <- function(object, ..., new.coef=NULL, warn=TRUE) {
   nip <- if(!inherits(object, "ippm")) 0 else
            length(attr(object$covfunargs, "free"))
   df <- length(coef(object)) + nip
+  ## compute adjustment constant
+  if(absolute && object$method %in% c("exact", "mpl", "ho")) {
+    X <- data.ppm(object)
+    W <- Window(X)
+    areaW <-
+      if(object$correction == "border" && object$rbord > 0) 
+      eroded.areas(W, object$rbord) else area(W)
+    constant <- areaW * markspace.integral(X)
+  } else constant <- 0
   ##
   if(is.null(new.coef)) {
     ## extract from object
-    ll <- object$maxlogpl
+    ll <- object$maxlogpl + constant
     attr(ll, "df") <- df
     class(ll) <- "logLik"
     return(ll)
@@ -592,7 +616,8 @@ logLik.ppm <- function(object, ..., new.coef=NULL, warn=TRUE) {
            w <- w.quad(Q)
            ll <- sum(log(cifdata[cifdata > 0])) - sum(w * cif)
          },
-         logi={
+         logi=,
+         VBlogi={
            B <- getglmdata(object, drop=TRUE)$.logi.B
            p <- cif/(B+cif)
            ll <- sum(log(p/(1-p))[Z]) + sum(log(1-p)) + sum(log(B[Z]))
@@ -600,11 +625,23 @@ logLik.ppm <- function(object, ..., new.coef=NULL, warn=TRUE) {
          stop(paste("Internal error: unrecognised ppm method:",
                     dQuote(method)))
          )
+  ll <- ll + constant
   attr(ll, "df") <- df
   class(ll) <- "logLik"
   return(ll)
 }
 
+pseudoR2 <- function(object, ...) {
+  UseMethod("pseudoR2")
+}
+
+pseudoR2.ppm <- function(object, ...) {
+  dres <- deviance(object, ..., warn=FALSE)
+  nullmod <- update(object, . ~ 1, forcefit=TRUE)
+  dnul <- deviance(nullmod, warn=FALSE)
+  return(1 - dres/dnul)
+}
+
 formula.ppm <- function(x, ...) {
   return(x$trend)
 }
